==> mupad-1.4.2.tgz: mupad/share/mmg/include/kernel/MCT_tar_table.h <==
#ifndef __MCT_tar_table__
#define __MCT_tar_table__


#define		kCHUNK_SIZE			40

typedef
long	MCLT_FP;

typedef
struct _MCLT_LibFileDesc
{	short	fUsed;
	long	fStart;
	long	fEnd;
	long	fLength;
	long	fPos;
	_MCLT_LibFileDesc() { fUsed = 0; }
}	MCLT_LibFileDesc;

	
class MCLT_LibFileTable
{
private:
	MCLT_LibFileDesc		*itsFileDesc;
	short					itsListSize;
	short					itsFreeDesc;
	short					itsUsedDesc;
		
public:
				MCLT_LibFileTable();
				~MCLT_LibFileTable();
				
	MCLT_FP		OpenFileEntry(long fStart, long fEnd);
	int			CloseFileEntry(MCLT_FP entry);
	void		CloseAllFileEntries(void);

	short		NumOpenFiles(void)							{ return(itsUsedDesc-1); }
	short		FileExists(MCLT_FP entry)					{ if( entry>=itsListSize || entry<1 ) return(0); else return( itsFileDesc[entry].fUsed ); 	}

	long		GetFileStart(MCLT_FP entry)					{ if( FileExists(entry) ) return( itsFileDesc[entry].fStart );  else return(-1); }
	long		GetFileEnd(MCLT_FP entry)					{ if( FileExists(entry) ) return( itsFileDesc[entry].fEnd );    else return(-1); }
	long		GetFileLength(MCLT_FP entry)				{ if( FileExists(entry) ) return( itsFileDesc[entry].fLength ); else return(-1); }
	long		GetFilePos(MCLT_FP entry)					{ if( FileExists(entry) ) return( itsFileDesc[entry].fPos );    else return(-1); }

	void		SetFilePos(MCLT_FP entry, long aPos)		{ if( FileExists(entry) ) itsFileDesc[entry].fPos    = aPos; 	}
	void		AdjustFilePos(MCLT_FP entry, long offset)	{ if( FileExists(entry) ) itsFileDesc[entry].fPos   += offset;	}
	
private:
	void		EnlargeDescList(void);
	
};


#endif

==> mupad-2.0.0.tgz: mupad/share/mmg/include/kernel/MCT_tar_table.h <==
#ifndef __MCT_tar_table__
#define __MCT_tar_table__


#define		kCHUNK_SIZE			40

typedef long MCLT_FP;

class MCLT_LibFileDesc
{
public:
	MCLT_LibFileDesc() { fUsed = 0; }
	short	fUsed;
	long	fStart;
	long	fEnd;
	long	fLength;
	long	fPos;
};


class MCLT_LibFileTable
{
private:
	MCLT_LibFileDesc		*itsFileDesc;
	short					itsListSize;
	short					itsFreeDesc;
	short					itsUsedDesc;

public:
				MCLT_LibFileTable();
				~MCLT_LibFileTable();

	MCLT_FP		OpenFileEntry(long fStart, long fEnd);
	int			CloseFileEntry(MCLT_FP entry);
	void		CloseAllFileEntries(void);

	short		NumOpenFiles(void)							{ return(itsUsedDesc-1); }
	short		FileExists(MCLT_FP entry)					{ if( entry>=itsListSize || entry<1 ) return(0); else return( itsFileDesc[entry].fUsed ); 	}

	long		GetFileStart(MCLT_FP entry)					{ if( FileExists(entry) ) return( itsFileDesc[entry].fStart );  else return(-1); }
	long		GetFileEnd(MCLT_FP entry)					{ if( FileExists(entry) ) return( itsFileDesc[entry].fEnd );    else return(-1); }
	long		GetFileLength(MCLT_FP entry)				{ if( FileExists(entry) ) return( itsFileDesc[entry].fLength ); else return(-1); }
	long		GetFilePos(MCLT_FP entry)					{ if( FileExists(entry) ) return( itsFileDesc[entry].fPos );    else return(-1); }

	void		SetFilePos(MCLT_FP entry, long aPos)		{ if( FileExists(entry) ) itsFileDesc[entry].fPos    = aPos; 	}
	void		AdjustFilePos(MCLT_FP entry, long offset)	{ if( FileExists(entry) ) itsFileDesc[entry].fPos   += offset;	}

private:
	void		EnlargeDescList(void);

};


#endif
